<?php
/**
 * Plugin Name: WPnet.pl - Show/hide header on scroll
 * Plugin URI:
 * Version: 1.0
 * Author: WPnet.pl
 * Author URI: http://wpnet.pl
 * License: GPL2
 *
 * @package WordPress
 */

/* Make sure we don't expose any info if called directly */
if ( ! function_exists( 'add_action' ) ) {
	exit;
}

/**
 * Load plugin textdomain.
 *
 * @return void
 */
function wpnet_shhos_load_textdomain() {
	load_plugin_textdomain( 'wpnet-shhos', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}
add_action( 'init', 'wpnet_shhos_load_textdomain' );

/**
 * Enqueue scripts
 *
 * @return void
 */
function wpnet_shhos_scripts() {
	if ( is_user_logged_in() ) {
		wp_register_script( 'wpnet-shhos-scripts', plugin_dir_url( __FILE__ ) . 'scripts.js', array( 'jquery' ), filemtime( plugin_dir_path( __FILE__ ) . 'scripts.js' ), true );
	} else {
		wp_register_script( 'wpnet-shhos-scripts', plugin_dir_url( __FILE__ ) . 'scripts.min.js', array( 'jquery' ), filemtime( plugin_dir_path( __FILE__ ) . 'scripts.js' ), true );
	}
	wp_enqueue_script( 'wpnet-shhos-scripts' );
}
add_action( 'wp_enqueue_scripts', 'wpnet_shhos_scripts' );

/**
 * Register settings
 *
 * @return void
 */
function wpnet_shhos_admin_init() {
	register_setting( 'wpnet_shhos_options', 'wpnet_shhos_min_scroll', 'intval' );
	register_setting( 'wpnet_shhos_options', 'wpnet_shhos_max_width', 'intval' );
	register_setting( 'wpnet_shhos_options', 'wpnet_shhos_sticky_adminbar' );
}
add_action( 'admin_init', 'wpnet_shhos_admin_init' );

/**
 * Set settings values
 *
 * @return void
 */
function wpnet_shhos_setup_options() {
	update_option( 'wpnet_shhos_min_scroll', '10' );
	update_option( 'wpnet_shhos_sticky_adminbar', 'on' );
	update_option( 'wpnet_shhos_max_width', '980' );
	wpnet_shhos_write_js_to_file();
}
register_activation_hook( __FILE__, 'wpnet_shhos_setup_options' );

/**
 * Add js to head
 *
 * @return void
 */
function wpnet_shhos_write_js_to_file() {
	global $wp_filesystem;

	$content = "
	( function( $ ) {
		$( window ).load( function() {
			let minScroll           = " . esc_attr( get_option( 'wpnet_shhos_min_scroll' ) ) . ",
				didScroll,
				lastScrollTop       = $( document ).scrollTop(),
				topHeader           = $( '#top-header' ),
				mainHeader          = $( '#main-header' ),
				wpadminbar          = $( '#wpadminbar' ),
				mainHeaderHeight    = mainHeader.outerHeight(),
				topHeaderHeight     = topHeader.length ? topHeader.outerHeight() : 0,
				wpadminbarHeight    = wpadminbar.length ? wpadminbar.outerHeight() : 0,
				mainHeaderTopOffset = mainHeaderHeight + topHeaderHeight + wpadminbarHeight,
				stickyAdminbar      = '" . esc_attr( get_option( 'wpnet_shhos_sticky_adminbar' ) ) . "',
				documentWidth       = $( document ).innerWidth();

			/* Add some custom styles */
			wpadminbar.add(topHeader).add(mainHeader).css( {
				'position' : 'fixed',
				'transition' : 'top .25s ease'
			} );

			$( window ).on( 'resize', function( e ) {
				wpadminbarHeight = wpadminbar.length ? wpadminbar.outerHeight() : 0;
				documentWidth    = $( document ).innerWidth();
				showHeader();
			} );

			$( window ).scroll( function( e ) {
				hasScrolled();
			} );

			/**
			* Show/hide header on scroll
			*/
			function hasScrolled() {
				if ( documentWidth <= " . esc_attr( get_option( 'wpnet_shhos_max_width' ) ) . " ) {
					let scrollTop = $( this ).scrollTop();

					/* Make sure the scrolled amount is more than minScroll */
					if ( Math.abs( lastScrollTop - scrollTop ) <= minScroll )
						return;

					if ( scrollTop > lastScrollTop && scrollTop > mainHeaderTopOffset ) {
						/* If the page's been scrolled down by more than the header height - hide the header. */
						hideHeader();
					} else if ( scrollTop + $( window ).height() < $( document ).height() ) {
						/* Show the header when scrolling up */
						showHeader();
					}
					/* Update the last scroll position */
					lastScrollTop = scrollTop;
				}
			}

			/**
			 * Hide header
			 */
			function hideHeader() {
				/* Hide admin bar ( if exists ) */
				if ( wpadminbar.length && stickyAdminbar != 'on' ) {
					$( '#wpadminbar' ).removeClass( 'nav-down' ).addClass( 'nav-up' );
					$( '#wpadminbar.nav-up' ).css( { 'top' : '-' + wpadminbarHeight + 'px' } );
				}

				/* Hide the main header */
				$( '#main-header' ).removeClass( 'nav-down' ).addClass( 'nav-up' );
				$( '#main-header.nav-up' ).css( { 'top' : stickyAdminbar == 'on' ? parseInt( wpadminbarHeight ) - parseInt( mainHeaderHeight ) : parseInt( - mainHeaderHeight ) + 'px' } );

				/* Hide the top header ( if exists ) */
				if ( topHeader.length ) {
					$( '#top-header' ).removeClass( 'nav-down' ).addClass( 'nav-up' );
					$( '#top-header.nav-up' ).css( { 'top' : stickyAdminbar == 'on' ? parseInt( wpadminbarHeight ) - parseInt( topHeaderHeight ) : parseInt( - topHeaderHeight ) + 'px' } );
				}

				/* Close dropdown menu */
				$( '#main-header .mobile_nav.opened .mobile_menu_bar_toggle' ).trigger( 'click' );
			}

			/**
			 * Show header
			 */
			function showHeader() {
				/* Show the main header */
				$( '#main-header' ).removeClass( 'nav-up' ).addClass( 'nav-down' );
				$( '#top-header.nav-down' ).css( { 'top' : `\${wpadminbarHeight}px` } );
				$( '#main-header.nav-down' ).css( { 'top' : `\${topHeaderHeight + wpadminbarHeight}px` } );
				/* Show the top header ( if exists ) */
				if ( topHeader.length ) {
					$( '#top-header' ).removeClass( 'nav-up' ).addClass( 'nav-down' );
					$( '#top-header.nav-down' ).css( { 'top' : `\${wpadminbarHeight}px` } );
				}
				/* Show admin bar ( if exists ) */
				if ( wpadminbar.length ) {
					$( '#wpadminbar' ).removeClass( 'nav-up' ).addClass( 'nav-down' );
					$( '#wpadminbar.nav-down' ).css( { 'top' : `0px` } );
				}
			}
		} );
	} )( jQuery );
	";

	// Save to file.
	$js_file     = plugin_dir_path( __FILE__ ) . 'scripts.js';
	$min_js_file = plugin_dir_path( __FILE__ ) . 'scripts.min.js';

	$wp_filesystem->put_contents( $js_file, $content );
	$wp_filesystem->put_contents( $min_js_file, minify_js( $content ) );
}
add_action( 'update_option_wpnet_shhos_min_scroll', 'wpnet_shhos_write_js_to_file', 10, 1 );
add_action( 'update_option_wpnet_shhos_max_width', 'wpnet_shhos_write_js_to_file', 10, 1 );
add_action( 'update_option_wpnet_shhos_sticky_adminbar', 'wpnet_shhos_write_js_to_file', 10, 1 );

/**
 * Generate settings page
 *
 * @return void
 */
function wpnet_shhos_settings_page() {
	?>
	<div class="wrap">
		<h2><?php esc_html_e( 'WPnet.pl - Show/hide header on scroll', 'wpnet-shhos' ); ?></h2>
		<form action="options.php" method="post" id="wpnet-shhos-options-form">
			<?php settings_fields( 'wpnet_shhos_options' ); ?>

			<table>
				<tr>
					<td>
						<label for="wpnet_shhos_min_scroll"><?php esc_html_e( 'Min scroll:', 'wpnet-shhos' ); ?></label>
					</td>
					<td>
						<input type="text" name="wpnet_shhos_min_scroll" id="wpnet_shhos_min_scroll" value="<?php echo esc_attr( get_option( 'wpnet_shhos_min_scroll' ) ); ?>"/>
					</td>
					<td>
						<?php esc_html_e( 'Minimum scroll at which the effect will be visible.', 'wpnet-shhos' ); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_shhos_max_width"><?php esc_html_e( 'Max width:', 'wpnet-shhos' ); ?></label>
					</td>
					<td>
						<input type="text" name="wpnet_shhos_max_width" id="wpnet_shhos_max_width" value="<?php echo esc_attr( get_option( 'wpnet_shhos_max_width' ) ); ?>"/>
					</td>
					<td>
						<?php esc_html_e( 'Maximum width at which the effect will be visible.', 'wpnet-shhos' ); ?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="wpnet_shhos_sticky_adminbar"><?php esc_html_e( 'Sticky admin bar:', 'wpnet-shhos' ); ?></label>
					</td>
					<td>
						<input type="checkbox" name="wpnet_shhos_sticky_adminbar" id="wpnet_shhos_sticky_adminbar" <?php echo ( get_option( 'wpnet_shhos_sticky_adminbar' ) ) ? 'checked="checked"' : ''; ?>/>
					</td>
					<td>
						<?php esc_html_e( 'Check if you want the admin bar to be always visible.', 'wpnet-shhos' ); ?>
					</td>
				</tr>
				<tr>
					<td>
					</td>
					<td>
						<input type="submit" name="submit" id="submit" class="button-primary" value="<?php esc_html_e( 'Save Changes' ); ?>" />
					</td>
					<td>
					</td>
				</tr>
			</table>
		</form>
	</div>
	<?php
}

/**
 * Add settings menu
 *
 * @return void
 */
function wpnet_shhos_settings_menu() {
	add_options_page( __( 'WPnet.pl - Show/hide header on scroll', 'wpnet-shhos' ), __( 'WPnet.pl - Show/hide header on scroll', 'wpnet-shhos' ), 'manage_options', 'wpnet-shhos.php', 'wpnet_shhos_settings_page' );
}
add_action( 'admin_menu', 'wpnet_shhos_settings_menu' );

/**
 * Minify js content
 *
 * @param string $content JS content.
 * @return string
 */
function minify_js( $content ) {
	$content = preg_replace(
		array(
			'/\n/',
			'/\s+/',
			'/\t+/',
			'/ +/',
			'/([\(\)\{\}:;<=>+-]) /',
			'/ ([\(\)\{\}:;<=>+-])/',
			'/(\/\*)+(.)*?(\*\/)/',
		),
		array(
			' ',
			' ',
			' ',
			' ',
			'$1',
			'$1',
			'',
		),
		$content
	);
	return $content;
}
